@@ -27,8 +27,6 @@
 #' @param search_string a text to search `x` for, will be checked with [as.ab()] if this value is not a column in `x`
 #' @param verbose a logical to indicate whether additional info should be printed
 #' @details You can look for an antibiotic (trade) name or abbreviation and it will search `x` and the [antibiotics] data set for any column containing a name or code of that antibiotic. **Longer columns names take precendence over shorter column names.**
-#' @importFrom dplyr %>% select filter_all any_vars
-#' @importFrom crayon blue
 #' @return A column name of `x`, or `NULL` when no result is found.
 #' @export
 #' @inheritSection AMR Read more on our website!
@@ -81,8 +79,8 @@ guess_ab_col <- function(x = NULL, search_string = NULL, verbose = FALSE) {
     if (search_string.ab %in% colnames(x)) {
       ab_result <- colnames(x)[colnames(x) == search_string.ab][1L]
 
-    } else if (any(tolower(colnames(x)) %in% tolower(unlist(ab_property(search_string.ab, "abbreviations"))))) {
-      ab_result <- colnames(x)[tolower(colnames(x)) %in% tolower(unlist(ab_property(search_string.ab, "abbreviations")))][1L]
+    } else if (any(tolower(colnames(x)) %in% tolower(unlist(ab_property(search_string.ab, "abbreviations", language = NULL))))) {
+      ab_result <- colnames(x)[tolower(colnames(x)) %in% tolower(unlist(ab_property(search_string.ab, "abbreviations", language = NULL)))][1L]
 
     } else {
       # sort colnames on length - longest first
@@ -98,28 +96,25 @@ guess_ab_col <- function(x = NULL, search_string = NULL, verbose = FALSE) {
   if (length(ab_result) == 0) {
     if (verbose == TRUE) {
       message(paste0("No column found as input for `", search_string,
-                     "` (", ab_name(search_string, language = "en", tolower = TRUE), ")."))
+                     "` (", ab_name(search_string, language = NULL, tolower = TRUE), ")."))
     }
     return(NULL)
   } else {
     if (verbose == TRUE) {
-      message(blue(paste0("NOTE: Using column `", bold(ab_result), "` as input for `", search_string,
-                          "` (", ab_name(search_string, language = "en", tolower = TRUE), ").")))
+      message(font_blue(paste0("NOTE: Using column `", font_bold(ab_result), "` as input for `", search_string,
+                          "` (", ab_name(search_string, language = NULL, tolower = TRUE), ").")))
     }
     return(ab_result)
   }
 }
 
-
-#' @importFrom crayon blue bold
-#' @importFrom dplyr %>% mutate arrange pull
 get_column_abx <- function(x,
                            soft_dependencies = NULL,
                            hard_dependencies = NULL,
                            verbose = FALSE,
                            ...) {
 
-  message(blue("NOTE: Auto-guessing columns suitable for analysis..."), appendLF = FALSE)
+  message(font_blue("NOTE: Auto-guessing columns suitable for analysis..."), appendLF = FALSE)
   
   x <- as.data.frame(x, stringsAsFactors = FALSE)
   x_bak <- x
@@ -173,16 +168,16 @@ get_column_abx <- function(x,
   x <- x[order(names(x), x)]
   
   # succeeded with aut-guessing
-  message(blue("OK."))
+  message(font_blue("OK."))
 
   for (i in seq_len(length(x))) {
     if (verbose == TRUE & !names(x[i]) %in% names(duplicates)) {
-      message(blue(paste0("NOTE: Using column `", bold(x[i]), "` as input for `", names(x)[i],
-                          "` (", ab_name(names(x)[i], tolower = TRUE), ").")))
+      message(font_blue(paste0("NOTE: Using column `", font_bold(x[i]), "` as input for `", names(x)[i],
+                          "` (", ab_name(names(x)[i], tolower = TRUE, language = NULL), ").")))
     }
     if (names(x[i]) %in% names(duplicates)) {
-      warning(red(paste0("Using column `", bold(x[i]), "` as input for `", names(x)[i],
-                         "` (", ab_name(names(x)[i], tolower = TRUE),
+      warning(font_red(paste0("Using column `", font_bold(x[i]), "` as input for `", names(x)[i],
+                         "` (", ab_name(names(x)[i], tolower = TRUE, language = NULL),
                          "), although it was matched for multiple antibiotics or columns.")), 
               call. = FALSE, 
               immediate. = verbose)
@@ -204,21 +199,18 @@ get_column_abx <- function(x,
     if (!all(soft_dependencies %in% names(x))) {
       # missing a soft dependency may lower the reliability
       missing <- soft_dependencies[!soft_dependencies %in% names(x)]
-      missing_txt <- data.frame(missing = missing,
-                                missing_names = ab_name(missing, tolower = TRUE),
-                                stringsAsFactors = FALSE) %>%
-        mutate(txt = paste0(bold(missing), " (", missing_names, ")")) %>%
-        arrange(missing_names) %>%
-        pull(txt)
-      message(blue("NOTE: Reliability will be improved if these antimicrobial results would be available too:",
-                   paste(missing_txt, collapse = ", ")))
+      missing_txt <- paste(paste0(ab_name(missing, tolower = TRUE, language = NULL), 
+                        " (", font_bold(missing, collapse = NULL), ")"), 
+                 collapse = ", ")
+      message(font_blue("NOTE: Reliability would be improved if these antimicrobial results would be available too:",
+                        missing_txt))
     }
   }
   x
 }
 
 generate_warning_abs_missing <- function(missing, any = FALSE) {
-  missing <- paste0(missing, " (", ab_name(missing, tolower = TRUE), ")")
+  missing <- paste0(missing, " (", ab_name(missing, tolower = TRUE, language = NULL), ")")
   if (any == TRUE) {
     any_txt <- c(" any of", "is")
   } else {
