@@ -19,13 +19,13 @@
 # Visit our website for more info: https://msberends.gitlab.io/AMR.    #
 # ==================================================================== #
 
-#' Use predefined reference data set
+#' User-defined reference data set for microorganisms
 #'
 #' @description These functions can be used to predefine your own reference to be used in [as.mo()] and consequently all `mo_*` functions like [mo_genus()] and [mo_gramstain()].
 #'
 #' This is **the fastest way** to have your organisation (or analysis) specific codes picked up and translated by this package.
 #' @inheritSection lifecycle Stable lifecycle
-#' @param path location of your reference file, see Details
+#' @param path location of your reference file, see Details. Can be `""`, `NULL` or `FALSE` to delete the reference file.
 #' @rdname mo_source
 #' @name mo_source
 #' @aliases set_mo_source get_mo_source
@@ -35,11 +35,12 @@
 #'
 #' [get_mo_source()] will return the data set by reading `"~/.mo_source.rds"` with [readRDS()]. If the original file has changed (the file defined with `path`), it will call [set_mo_source()] to update the data file automatically.
 #'
-#' Reading an Excel file (`.xlsx`) with only one row has a size of 8-9 kB. The compressed file used by this package will have a size of 0.1 kB and can be read by [get_mo_source()] in only a couple of microseconds (a millionth of a second).
+#' Reading an Excel file (`.xlsx`) with only one row has a size of 8-9 kB. The compressed file created with [set_mo_source()] will then have a size of 0.1 kB and can be read by [get_mo_source()] in only a couple of microseconds (millionths of a second).
 #' 
-#' ## How it works
+#' @section How to setup:
+#' 
+#' Imagine this data on a sheet of an Excel file (mo codes were looked up in the [microorganisms] data set). The first column contains the organisation specific codes, the second column contains an MO code from this package:
 #' 
-#' Imagine this data on a sheet of an Excel file (mo codes were looked up in the `microorganisms` data set). The first column contains the organisation specific codes, the second column contains an MO code from this package:
 #' ```
 #'   |         A          |       B      |
 #' --|--------------------|--------------|
@@ -50,27 +51,31 @@
 #' ```
 #'
 #' We save it as `"home/me/ourcodes.xlsx"`. Now we have to set it as a source:
+#' 
 #' ```
 #' set_mo_source("home/me/ourcodes.xlsx")
-#' # Created mo_source file '~/.mo_source.rds' from 'home/me/ourcodes.xlsx'.
+#' #> NOTE: Created mo_source file '~/.mo_source.rds' from 'home/me/ourcodes.xlsx'
+#' #>       (columns "Organisation XYZ" and "mo")
 #' ```
 #'
-#' It has now created a file `"~/.mo_source.rds"` with the contents of our Excel file, but only the first column with foreign values and the 'mo' column will be kept.
+#' It has now created a file `"~/.mo_source.rds"` with the contents of our Excel file. Only the first column with foreign values and the 'mo' column will be kept when creating the RDS file.
 #'
 #' And now we can use it in our functions:
+#' 
 #' ```
 #' as.mo("lab_mo_ecoli")
-#' [1] B_ESCHR_COLI
+#' #> [1] B_ESCHR_COLI
 #'
 #' mo_genus("lab_mo_kpneumoniae")
-#' [1] "Klebsiella"
+#' #> [1] "Klebsiella"
 #'
 #' # other input values still work too
 #' as.mo(c("Escherichia coli", "E. coli", "lab_mo_ecoli"))
-#' [1] B_ESCHR_COLI B_ESCHR_COLI B_ESCHR_COLI
+#' #> [1] B_ESCHR_COLI B_ESCHR_COLI B_ESCHR_COLI
 #' ```
 #'
-#' If we edit the Excel file to, let's say, by adding row 4 like this:
+#' If we edit the Excel file by, let's say, adding row 4 like this:
+#' 
 #' ```
 #'   |         A          |       B      |
 #' --|--------------------|--------------|
@@ -82,37 +87,41 @@
 #' ```
 #'
 #' ...any new usage of an MO function in this package will update your data file:
+#' 
 #' ```
 #' as.mo("lab_mo_ecoli")
-#' # Updated mo_source file '~/.mo_source.rds' from 'home/me/ourcodes.xlsx'.
-#' [1] B_ESCHR_COLI
+#' #> NOTE: Updated mo_source file '~/.mo_source.rds' from 'home/me/ourcodes.xlsx'
+#' #>       (columns "Organisation XYZ" and "mo")
+#' #> [1] B_ESCHR_COLI
 #'
 #' mo_genus("lab_Staph_aureus")
-#' [1] "Staphylococcus"
+#' #> [1] "Staphylococcus"
 #' ```
 #'
-#' To remove the reference data file completely, just use `""` or `NULL` as input for `[set_mo_source()]`:
+#' To delete the reference data file, just use `""`, `NULL` or `FALSE` as input for [set_mo_source()]:
+#' 
 #' ```
 #' set_mo_source(NULL)
 #' # Removed mo_source file '~/.mo_source.rds'.
 #' ```
-#' @importFrom dplyr select everything
+#' 
+#' If the original Excel file is moved or deleted, the mo_source file will be removed upon the next use of [as.mo()]. If the mo_source file is manually deleted (i.e. without using [set_mo_source()]), the references to the mo_source file will be removed upon the next use of [as.mo()].
 #' @export
 #' @inheritSection AMR Read more on our website!
 set_mo_source <- function(path) {
 
   file_location <- path.expand("~/mo_source.rds")
 
-  if (!is.character(path) | length(path) > 1) {
-    stop("`path` must be a character of length 1.")
+  if (length(path) > 1) {
+    stop("`path` must be of length 1.")
   }
 
-  if (path %in% c(NULL, "")) {
+  if (is.null(path) || path %in% c(FALSE, "")) {
     options(mo_source = NULL)
     options(mo_source_timestamp = NULL)
     if (file.exists(file_location)) {
       unlink(file_location)
-      message("Removed mo_source file '", file_location, "'.")
+      message(font_red(paste0("Removed mo_source file '", font_bold(file_location), "'")))
     }
     return(invisible())
   }
@@ -127,7 +136,8 @@ set_mo_source <- function(path) {
   } else if (path %like% "[.]xlsx?$") {
     # is Excel file (old or new)
     stopifnot_installed_package("readxl")
-    df <- readxl::read_excel(path)
+    read_excel <- get("read_excel", envir = asNamespace("readxl"))
+    df <- read_excel(path)
 
   } else if (path %like% "[.]tsv$") {
     df <- utils::read.table(header = TRUE, sep = "\t", stringsAsFactors = FALSE)
@@ -137,13 +147,13 @@ set_mo_source <- function(path) {
     try(
       df <- utils::read.table(header = TRUE, sep = ",", stringsAsFactors = FALSE),
       silent = TRUE)
-    if (!mo_source_isvalid(df)) {
+    if (!mo_source_isvalid(df, stop_on_error = FALSE)) {
       # try tab
       try(
         df <- utils::read.table(header = TRUE, sep = "\t", stringsAsFactors = FALSE),
         silent = TRUE)
     }
-    if (!mo_source_isvalid(df)) {
+    if (!mo_source_isvalid(df, stop_on_error = FALSE)) {
       # try pipe
       try(
         df <- utils::read.table(header = TRUE, sep = "|", stringsAsFactors = FALSE),
@@ -151,17 +161,16 @@ set_mo_source <- function(path) {
     }
   }
 
-  if (!mo_source_isvalid(df)) {
-    stop("File must contain a column with self-defined values and a reference column `mo` with valid values from the `microorganisms` data set.")
-  }
+  # check integrity
+  mo_source_isvalid(df)
 
-  df <- df %>% filter(!is.na(mo))
+  df <- subset(df, !is.na(mo))
 
   # keep only first two columns, second must be mo
   if (colnames(df)[1] == "mo") {
-    df <- df[, c(2, 1)]
+    df <- df[, c(colnames(df)[2], "mo")]
   } else {
-    df <- df[, c(1, 2)]
+    df <- df[, c(colnames(df)[1], "mo")]
   }
 
   df <- as.data.frame(df, stringAsFactors = FALSE)
@@ -175,33 +184,43 @@ set_mo_source <- function(path) {
   saveRDS(df, file_location)
   options(mo_source = path)
   options(mo_source_timestamp = as.character(file.info(path)$mtime))
-  message(action, " mo_source file '", file_location, "' from '", path, "'.")
+  message(font_blue(paste0("NOTE: ",
+                           action, " mo_source file '", font_bold(file_location), "'",
+                           " from '", font_bold(path), "'",
+                           '\n      (columns "', colnames(df)[1], '" and "', colnames(df)[2], '")')))
 }
 
 #' @rdname mo_source
 #' @export
 get_mo_source <- function() {
   if (is.null(getOption("mo_source", NULL))) {
-    NULL
-  } else {
-    old_time <- as.POSIXct(getOption("mo_source_timestamp"))
-    new_time <- as.POSIXct(as.character(file.info(getOption("mo_source", ""))$mtime))
-
-    if (is.na(new_time)) {
-      # source file was deleted, remove reference too
-      set_mo_source("")
-      return(NULL)
-    }
-    if (new_time != old_time) {
-      # set updated source
-      set_mo_source(getOption("mo_source"))
-    }
-    file_location <- path.expand("~/mo_source.rds")
-    readRDS(file_location)
+    return(NULL)
   }
+  
+  if (!file.exists(path.expand("~/mo_source.rds"))) {
+    options(mo_source = NULL)
+    options(mo_source_timestamp = NULL)
+    message(font_blue("NOTE: Removed references to deleted mo_source file (see ?mo_source)"))
+    return(NULL)
+  }
+  
+  old_time <- as.POSIXct(getOption("mo_source_timestamp"))
+  new_time <- as.POSIXct(as.character(file.info(getOption("mo_source", ""))$mtime))
+  
+  if (is.na(new_time)) {
+    # source file was deleted, remove reference too
+    set_mo_source("")
+    return(NULL)
+  }
+  if (new_time != old_time) {
+    # set updated source
+    set_mo_source(getOption("mo_source"))
+  }
+  file_location <- path.expand("~/mo_source.rds")
+  readRDS(file_location)
 }
 
-mo_source_isvalid <- function(x) {
+mo_source_isvalid <- function(x, refer_to_name = "`reference_df`", stop_on_error = TRUE) {
   
   check_dataset_integrity()
   
@@ -212,13 +231,41 @@ mo_source_isvalid <- function(x) {
     return(TRUE)
   }
   if (is.null(x)) {
-    return(TRUE)
+    if (stop_on_error == TRUE) {
+      stop(refer_to_name, " cannot be NULL.", call. = FALSE)
+    } else {
+      return(FALSE)
+    }
   }
   if (!is.data.frame(x)) {
-    return(FALSE)
+    if (stop_on_error == TRUE) {
+      stop(refer_to_name, " must be a data.frame.", call. = FALSE)
+    } else {
+      return(FALSE)
+    }
   }
   if (!"mo" %in% colnames(x)) {
-    return(FALSE)
+    if (stop_on_error == TRUE) {
+      stop(refer_to_name, " must contain a column 'mo'.", call. = FALSE)
+    } else {
+      return(FALSE)
+    }
   }
-  all(x$mo %in% c("", microorganisms$mo, microorganisms.translation$mo_old), na.rm = TRUE)
+  if (!all(x$mo %in% c("", microorganisms$mo, microorganisms.translation$mo_old), na.rm = TRUE)) {
+    if (stop_on_error == TRUE) {
+      invalid <- x[which(!x$mo %in% c("", microorganisms$mo, microorganisms.translation$mo_old)), , drop = FALSE]
+      if (nrow(invalid) > 1) {
+        plural <- "s"
+      } else {
+        plural <- ""
+      }
+      stop("Value", plural, " ", paste0("'", invalid[, 1, drop = TRUE], "'", collapse = ", "), 
+           " found in ", tolower(refer_to_name), 
+           ", but with invalid microorganism code", plural, " ", paste0("'", invalid$mo, "'", collapse = ", "), ".",
+           call. = FALSE)
+    } else {
+      return(FALSE)
+    }
+  }
+  TRUE
 }
