@@ -47,10 +47,8 @@ test_that("joins work", {
 
   expect_equal(nrow(inner_join_microorganisms("B_ESCHR_COLI")), 1)
   expect_equal(nrow(inner_join_microorganisms("B_ESCHR_COLI", by = c("mo" = "mo"))), 1)
-  expect_warning(inner_join_microorganisms("Escherichia", by = c("mo" = "genus")))
 
   expect_equal(nrow(left_join_microorganisms("B_ESCHR_COLI")), 1)
-  expect_warning(left_join_microorganisms("Escherichia", by = c("mo" = "genus")))
 
   expect_equal(nrow(semi_join_microorganisms("B_ESCHR_COLI")), 1)
   expect_equal(nrow(anti_join_microorganisms("B_ESCHR_COLI")), 0)
